![logo](liionpack.png)

# Welcome to liionpack

The lithium-ion battery pack simulator powered by [PyBaMM](https://www.pybamm.org/). Liionpack allows you to specify pack configurations with numbers of cells connected in series and parallel or by uploading a netlist.

Leverage the experiments and parameter sets from PyBaMM and scale up your simulations to pack level. Include thermal effects and account for pack position dependency with variable inputs for heat transfer.

Include statistical distributions in the battery parameters.
